@@ -1,13 +1,13 @@
 package Log::ger::Output::String;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-31'; # DATE
-our $DIST = 'Log-ger'; # DIST
-our $VERSION = '0.038'; # VERSION
-
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-06-10'; # DATE
+our $DIST = 'Log-ger'; # DIST
+our $VERSION = '0.039'; # VERSION
+
 sub meta { +{
     v => 2,
 } }
@@ -57,11 +57,11 @@ Log::ger::Output::String - Set output to a string
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
- use var '$str';
+ BEGIN { our '$str' }
  use Log::ger::Output 'String' => (
      string => \$str,
      # append_newline => 0, # default is true, to mimic Log::ger::Output::Screen
@@ -97,7 +97,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
