@@ -1,13 +1,13 @@
 package Log::ger::Util;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-31'; # DATE
-our $DIST = 'Log-ger'; # DIST
-our $VERSION = '0.038'; # VERSION
-
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-06-10'; # DATE
+our $DIST = 'Log-ger'; # DIST
+our $VERSION = '0.039'; # VERSION
+
 require Log::ger;
 require Log::ger::Heavy;
 
@@ -221,7 +221,7 @@ sub set_plugin {
     if ($args{hooks}) {
         $hooks = $args{hooks};
     } else {
-        no strict 'refs';
+        no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
         my $prefix = $args{prefix} || 'Log::ger::Plugin::';
         my $mod = $args{name};
         $mod = $prefix . $mod unless index($mod, $prefix) == 0;
@@ -306,7 +306,7 @@ Log::ger::Util - Utility routines for Log::ger
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 DESCRIPTION
 
@@ -320,7 +320,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
